@@ -48,6 +48,7 @@ if TYPE_CHECKING:
     from libqtile.group import _Group
     from libqtile.layout.base import Layout
     from libqtile.lazy import LazyCall
+    from libqtile.utils import ColorType
 
 
 class Key:
@@ -61,7 +62,8 @@ class Key:
         ``"shift"``, ``"lock"``, ``"control"``, ``"mod1"``, ``"mod2"``, ``"mod3"``,
         ``"mod4"``, ``"mod5"``.
     key:
-        A key specification, e.g. ``"a"``, ``"Tab"``, ``"Return"``, ``"space"``.
+        A key specification, e.g. ``"a"``, ``"Tab"``, ``"Return"``, ``"space"``. Also accepts
+        an integer value representing a keycode.
     commands:
         One or more :class:`LazyCall` objects to evaluate in sequence upon keypress. Multiple
         commands should be separated by commas.
@@ -75,7 +77,7 @@ class Key:
     def __init__(
         self,
         modifiers: list[str],
-        key: str,
+        key: str | int,
         *commands: LazyCall,
         desc: str = "",
         swallow: bool = True,
@@ -101,7 +103,8 @@ class KeyChord:
         ``"shift"``, ``"lock"``, ``"control"``, ``"mod1"``, ``"mod2"``, ``"mod3"``,
         ``"mod4"``, ``"mod5"``.
     key:
-        A key specification, e.g. ``"a"``, ``"Tab"``, ``"Return"``, ``"space"``.
+        A key specification, e.g. ``"a"``, ``"Tab"``, ``"Return"``, ``"space"``. Also accepts
+        an integer value representing a keycode.
     submappings:
         A list of :class:`Key` or :class:`KeyChord` declarations to bind in this chord.
     mode:
@@ -123,7 +126,7 @@ class KeyChord:
     def __init__(
         self,
         modifiers: list[str],
-        key: str,
+        key: str | int,
         submappings: list[Key | KeyChord],
         mode: bool | str = False,
         name: str = "",
@@ -403,6 +406,10 @@ class Screen(CommandObject):
     ``x``, ``y``, ``width``, and ``height`` aren't specified usually unless you are
     using 'fake screens'.
 
+    The ``background`` parameter, if given, should be a valid single colour. This will
+    paint a solid background colour to the screen. Note, the setting is ignored if
+    ``wallpaper`` is also set (see below).
+
     The ``wallpaper`` parameter, if given, should be a path to an image file. How this
     image is painted to the screen is specified by the ``wallpaper_mode`` parameter. By
     default, the image will be placed at the screens origin and retain its own
@@ -423,6 +430,7 @@ class Screen(CommandObject):
         bottom: BarType | None = None,
         left: BarType | None = None,
         right: BarType | None = None,
+        background: ColorType | None = None,
         wallpaper: str | None = None,
         wallpaper_mode: str | None = None,
         x11_drag_polling_rate: int | None = None,
@@ -435,6 +443,7 @@ class Screen(CommandObject):
         self.bottom = bottom
         self.left = left
         self.right = right
+        self.background = background
         self.wallpaper = wallpaper
         self.wallpaper_mode = wallpaper_mode
         self.x11_drag_polling_rate = x11_drag_polling_rate
@@ -468,9 +477,12 @@ class Screen(CommandObject):
         for i in self.gaps:
             i._configure(qtile, self, reconfigure=reconfigure_gaps)
         self.set_group(group)
+
         if self.wallpaper:
             self.wallpaper = os.path.expanduser(self.wallpaper)
             self.paint(self.wallpaper, self.wallpaper_mode)
+        elif self.background:
+            self.qtile.fill_screen(self, self.background)
 
     def paint(self, path: str, mode: str | None = None) -> None:
         if self.qtile:
